# Work OS IPython Custom Magic

IPython Custom Magic that helps define a Work OS Smart Docs.

## Requirements

* JupyterLab >= 3.0

## Install

To install the custom magics, execute:

```bash
pip install work_os_ipython_magic
```

Then in your Notebook, you need to load this custom magic:

```python
import work_os_ipython_magic
%load_ext work_os_ipython_magic
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall work_os_ipython_magic
```
